@@ -1,7 +1,6 @@
 import logging
 import time
-
-from six.moves.queue import Queue
+from queue import Queue
 
 from task_processing.interfaces.runner import Runner
 
